import { ExternalAttachment, ExternalAttachmentFactoryOptions } from './external';
import { AttachmentType, kSerializeData } from '../../utils/constants';
export interface IStickerImage {
    url: string;
    width: number;
    height: number;
}
export interface IStickerAttachmentPayload {
    sticker_id: number;
    product_id: number;
    images: IStickerImage[];
    images_with_background: IStickerImage[];
}
export type StickerAttachmentOptions = ExternalAttachmentFactoryOptions<IStickerAttachmentPayload>;
export declare class StickerAttachment extends ExternalAttachment<IStickerAttachmentPayload, AttachmentType.STICKER | 'sticker'> {
    /**
     * Constructor
     */
    constructor(options: StickerAttachmentOptions);
    /**
     * Returns the identifier sticker
     */
    get id(): number;
    /**
     * Returns the identifier product
     */
    get productId(): number;
    /**
     * Returns the images sizes
     */
    get images(): IStickerImage[];
    /**
     * Returns the images sizes with backgrounds
     */
    get imagesWithBackground(): IStickerImage[];
    /**
     * Returns the custom data
     */
    [kSerializeData](): object;
}
